Documentation
¶
Overview ¶
Copyright (c) 2016-2019 Uber Technologies, Inc.
Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at
http://www.apache.org/licenses/LICENSE-2.0
Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func EmitDownloadPerformance ¶
func EmitDownloadPerformance(stats tally.Scope, downloadType DownloadType, sizeBytes int64, t time.Duration)
EmitDownloadPerformance emits metrics (usually latency and throughput) on the download performance of a blob. Check the respective DownloadType for more context.
Types ¶
type DownloadType ¶
type DownloadType string
const ( // Measures the end-to-end download of a torrent (blob) in agent, including the GetMetainfo call. TORRENT_DOWNLOAD DownloadType = "TORRENT_DOWNLOAD" // Measures the torrent leeching throughput from peers. EXCLUDES any other parts of the download, e.g. the GetMetainfo call. TORRENT_LEECH DownloadType = "TORRENT_LEECH" // Measures the client-side GetMetainfo call performance. METAINFO_DOWNLOAD DownloadType = "METAINFO_DOWNLOAD" // Measures the e2e blob download from remote storage (e.g. GCS) in origin/build-index. REMOTE_DOWNLOAD DownloadType = "REMOTE_DOWNLOAD" // Measures the e2e blob download performance of a blob from proxy. PROXY_BLOB_DOWNLOAD = "PROXY_BLOB_DOWNLOAD" )