dockerutil

package
v0.1.24 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 10, 2026 License: Apache-2.0 Imports: 9 Imported by: 6

Documentation

Overview

Copyright (c) 2016-2019 Uber Technologies, Inc.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Copyright (c) 2016-2019 Uber Technologies, Inc.

Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with the License. You may obtain a copy of the License at

http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the specific language governing permissions and limitations under the License.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetManifestReferences

func GetManifestReferences(manifest distribution.Manifest) ([]core.Digest, error)

GetManifestReferences returns a list of references by a manifest.

func GetSupportedManifestTypes added in v0.1.6

func GetSupportedManifestTypes() string

func ManifestFixture

func ManifestFixture(config core.Digest, layer1 core.Digest, layer2 core.Digest) (core.Digest, []byte)

ManifestFixture creates a manifest blob for testing purposes.

func ManifestListFixture added in v0.1.23

func ManifestListFixture(manifest1 core.Digest, manifest2 core.Digest) (core.Digest, []byte)

ManifestListFixture creates a manifest list blob for testing purposes.

func OCIIndexFixture added in v0.1.24

func OCIIndexFixture(manifest1 core.Digest, manifest2 core.Digest) (core.Digest, []byte)

OCIIndexFixture creates an OCI image index blob for testing purposes.

func OCIManifestFixture added in v0.1.24

func OCIManifestFixture(config core.Digest, layer1 core.Digest, layer2 core.Digest) (core.Digest, []byte)

OCIManifestFixture creates an OCI image manifest blob for testing purposes.

func ParseManifest added in v0.1.6

func ParseManifest(r io.Reader) (distribution.Manifest, core.Digest, error)

Types

This section is empty.

Jump to